@@ -1,4 +1,5 @@
 from txhttputil.site.BasicResource import BasicResource
+from vortex.VortexFactory import VortexFactory
 
 from peek_logic_service.server.sw_download.PeekSwDownloadResource import (
     PeekSwUpdateDownloadResource,
@@ -6,6 +7,7 @@ from peek_logic_service.server.sw_download.PeekSwDownloadResource import (
 from peek_logic_service.server.sw_download.PluginSwDownloadResource import (
     PluginSwDownloadResource,
 )
+from peek_platform import PeekPlatformConfig
 
 platformSiteRoot = BasicResource()
 
@@ -19,5 +21,10 @@ def setupPlatformSite():
 
     # Add the plugin download resource
     platformSiteRoot.putChild(
-        b"peek_logic_service.sw_install.plugin.download", PluginSwDownloadResource()
+        b"peek_logic_service.sw_install.plugin.download",
+        PluginSwDownloadResource(),
     )
+    vortexWebsocketResource = VortexFactory.createHttpWebsocketResource(
+        PeekPlatformConfig.componentName
+    )
+    platformSiteRoot.putChild(b"vortexws", vortexWebsocketResource)
